Multiplier

Struct Multiplier 

pub struct Multiplier(pub i64, pub i16);
The multiplier of a TimeUnit.

The multiplier consists of two numbers (m, e) which are applied to another number x as follows:

x * m * 10 ^ e

Examples:

let nano_second = Multiplier(1, -9);
let second = Multiplier(1, 0);
let hour = Multiplier(3600, 0);

Tuple Fields

0: i641: i16

Implementations

Source

impl Multiplier

pub const fn coefficient(&self) -> i64

Return the coefficient component of the Multiplier

Examples
use fundu_core::time::Multiplier;

let multiplier = Multiplier(123, 45);
assert_eq!(multiplier.coefficient(), 123);
pub const fn exponent(&self) -> i16

Return the exponent component of the Multiplier

Examples
use fundu_core::time::Multiplier;

let multiplier = Multiplier(123, 45);
assert_eq!(multiplier.exponent(), 45);
pub const fn is_negative(&self) -> bool

Return true if the Multiplier is negative

Examples
use fundu_core::time::Multiplier;

let multiplier = Multiplier(-123, 45);
assert!(multiplier.is_negative());
pub const fn is_positive(&self) -> bool

Return true if the Multiplier is positive

Examples
use fundu_core::time::Multiplier;

let multiplier = Multiplier(123, 45);
assert!(multiplier.is_positive());
pub const fn checked_mul(&self, rhs: Self) -> Option<Self>

Checked Multiplier multiplication. Computes self * other, returning None if an overflow occurred.

Let a, b be multipliers, with m being the coefficient and e the exponent. The multiplication is performed such that (x.m, x.e) = (a.m * b.m, a.e + b.e)

Examples
use fundu_core::time::Multiplier;

assert_eq!(
    Multiplier(1, 2).checked_mul(Multiplier(3, 4)),
    Some(Multiplier(3, 6))
);
assert_eq!(
    Multiplier(-1, 2).checked_mul(Multiplier(3, -4)),
    Some(Multiplier(-3, -2))
);
assert_eq!(Multiplier(2, 0).checked_mul(Multiplier(i64::MAX, 1)), None);
assert_eq!(Multiplier(1, 2).checked_mul(Multiplier(1, i16::MAX)), None);
pub const fn saturating_neg(&self) -> Self

Saturating negation. Computes -self, returning i64::MAX if self.coefficient() == i64::MIN instead of overflowing.

Examples
use fundu_core::time::Multiplier;

assert_eq!(Multiplier(1, 2).saturating_neg(), Multiplier(-1, 2));
assert_eq!(Multiplier(-1, 2).saturating_neg(), Multiplier(1, 2));
assert_eq!(
    Multiplier(i64::MIN, 2).saturating_neg(),
    Multiplier(i64::MAX, 2)
);